complex_doc_2.pdf

## Metadata

Title | complex_doc_2.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\complex_doc_2.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230325085752+00'00'
PDF Metadata: modDate | D:20230325085752+00'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0
2. h1 :: A Test Document
3. h3 :: A Second Title
4. h4 :: An Aside
5. h5 :: List Title
6. h5 :: 5. sodales. Donec sit amet egestas

#### Page 0

No images

Path: | content.0.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 216.3805389404297
y1 |  | 96.10997772216797
y0 |  | 76.06997680664062
x0 |  | 72.02400207519531

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 226.85813903808594
y1 |  | 155.32997131347656
y0 |  | 139.36996459960938
x0 |  | 132.13999938964844

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 456.2800598144531
y1 |  | 277.4599609375
y0 |  | 157.66995239257812
x0 |  | 132.13999938964844

Path: | content.0.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 455.8179016113281
y1 |  | 389.1799621582031
y0 |  | 293.7799987792969
x0 |  | 132.13999938964844

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 281.65966796875
y1 |  | 559.0
y0 |  | 427.1199951171875
x0 |  | 72.02400207519531

Path: | content.0.[5,5].bbox
Type: | addition

Key | Old | New
x1 |  | 252.5
y1 |  | 764.699951171875
y0 |  | 584.3999633789062
x0 |  | 82.0

Path: | content.0.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 522.5587158203125
y1 |  | 599.8599853515625
y0 |  | 441.03997802734375
x0 |  | 315.42999267578125

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 354.2973327636719
y1 |  | 626.739990234375
y0 |  | 616.1799926757812
x0 |  | 315.42999267578125

Path: | content.0.[8,8].bbox
Type: | addition

Key | Old | New
x1 |  | 522.2313232421875
y1 |  | 743.4000244140625
y0 |  | 642.7179565429688
x0 |  | 333.42999267578125

Path: | content.0.[9,9].bbox
Type: | addition

Key | Old | New
x1 |  | 489.44732666015625
y1 |  | 756.1199951171875
y0 |  | 745.2179565429688
x0 |  | 333.42999267578125

# A Test Document

### A Second Title

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur non vestibulum augue. Maecenas porta dapibus libero in fringilla. Phasellus suscipit dignissim lacus, eu imperdiet neque tempor vitae. Nulla vehicula sapien a urna pellentesque ultricies. Etiam blandit accumsan justo, a sodales risus. Vestibulum vehicula diam malesuada nisi venenatis mollis. Duis finibus ante sit amet congue facilisis. Fusce aliquam lectus a risus pulvinar pretium. Maecenas aliquet arcu non iaculis laoreet. Donec accumsan urna eget lacinia dapibus. Sed purus orci, congue at vehicula id, venenatis ut quam. Nam vel sodales ligula, ut sodales nisl. Vestibulum justo augue, laoreet sit amet venenatis at, suscipit nec lectus. Sed id augue dapibus, sodales nisl ut, volutpat purus.

Fusce luctus, ligula sit amet volutpat pretium, nisi urna ultrices libero, eu vestibulum nunc metus ut neque. Nullam sapien arcu, vestibulum sit amet scelerisque ut, tincidunt eget quam. Aliquam at venenatis urna. Etiam sollicitudin convallis sapien id auctor. Pellentesque non nibh quis massa blandit sollicitudin sit amet eu velit. Duis sollicitudin metus cursus, suscipit felis nec, sollicitudin dui. Nullam euismod, lacus vel commodo aliquet, lacus quam aliquam nunc, id faucibus nulla dolor eget lorem. Nunc accumsan maximus est in consequat. In hac habitasse platea dictumst.

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur egestas tellus ut ante dictum accumsan. Curabitur vel imperdiet tortor, vestibulum accumsan libero. Ut ac elementum nulla. Ut sit amet faucibus risus. Curabitur maximus urna non lectus bibendum finibus. Duis eget eleifend sapien. Suspendisse potenti. Donec neque lorem, scelerisque non sollicitudin sed, molestie a eros. Donec sed turpis sit amet dui vestibulum fringilla. Integer ut enim sit amet sem vestibulum efficitur et vel ante.

#### An Aside

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur egestas tellus ut ante dictum accumsan. Curabitur vel imperdiet tortor, vestibulum accumsan libero. Ut ac elementum nulla. Ut sit amet faucibus risus. Curabitur maximus urna non lectus bibendum finibus. Duis eget eleifend sapien. Suspendisse potenti.

Aliquam gravida ipsum non enim accumsan, ut lobortis lacus egestas. Quisque justo nulla, semper ut ligula vitae, dictum lobortis enim. Sed eu nunc pellentesque, ultricies risus eu, gravida justo. Praesent nibh massa, sollicitudin a orci sed, iaculis egestas neque. Integer vestibulum auctor odio, et tempus urna tincidunt sed. Maecenas sit amet nunc at risus varius sodales at sit amet est. Nulla efficitur molestie nisi eget semper. Donec in tempus nisi, id dictum metus. Sed consectetur diam at metus rutrum pulvinar. Nullam pellentesque dolor vel viverra efficitur. Maecenas fermentum varius .

##### List Title

1. Suspendisse commodo condimentum dolor, eu consectetur

2. dui posuere sed. Curabitur eros

3. sem, venenatis consectetur ultricies in, vehicula sodales felis.

4. Donec sem est, pulvinar ac justo sed, posuere malesuada justo. Vivamus sagittis at tortor vitae

##### 5. sodales. Donec sit amet egestas

# A Test Document

### A Second Title

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur non vestibulum augue. Maecenas porta dapibus libero in fringilla. Phasellus suscipit dignissim lacus, eu imperdiet neque tempor vitae. Nulla vehicula sapien a urna pellentesque ultricies. Etiam blandit accumsan justo, a sodales risus. Vestibulum vehicula diam malesuada nisi venenatis mollis. Duis finibus ante sit amet congue facilisis. Fusce aliquam lectus a risus pulvinar pretium. Maecenas aliquet arcu non iaculis laoreet. Donec accumsan urna eget lacinia dapibus. Sed purus orci, congue at vehicula id, venenatis ut quam. Nam vel sodales ligula, ut sodales nisl. Vestibulum justo augue, laoreet sit amet venenatis at, suscipit nec lectus. Sed id augue dapibus, sodales nisl ut, volutpat purus.

Fusce luctus, ligula sit amet volutpat pretium, nisi urna ultrices libero, eu vestibulum nunc metus ut neque. Nullam sapien arcu, vestibulum sit amet scelerisque ut, tincidunt eget quam. Aliquam at venenatis urna. Etiam sollicitudin convallis sapien id auctor. Pellentesque non nibh quis massa blandit sollicitudin sit amet eu velit. Duis sollicitudin metus cursus, suscipit felis nec, sollicitudin dui. Nullam euismod, lacus vel commodo aliquet, lacus quam aliquam nunc, id faucibus nulla dolor eget lorem. Nunc accumsan maximus est in consequat. In hac habitasse platea dictumst.

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur egestas tellus ut ante dictum accumsan. Curabitur vel imperdiet tortor, vestibulum accumsan libero. Ut ac elementum nulla. Ut sit amet faucibus risus. Curabitur maximus urna non lectus bibendum finibus. Duis eget eleifend sapien. Suspendisse potenti. Donec neque lorem, scelerisque non sollicitudin sed, molestie a eros. Donec sed turpis sit amet dui vestibulum fringilla. Integer ut enim sit amet sem vestibulum efficitur et vel ante.

#### An Aside

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur egestas tellus ut ante dictum accumsan. Curabitur vel imperdiet tortor, vestibulum accumsan libero. Ut ac elementum nulla. Ut sit amet faucibus risus. Curabitur maximus urna non lectus bibendum finibus. Duis eget eleifend sapien. Suspendisse potenti.

Aliquam gravida ipsum non enim accumsan, ut lobortis lacus egestas. Quisque justo nulla, semper ut ligula vitae, dictum lobortis enim. Sed eu nunc pellentesque, ultricies risus eu, gravida justo. Praesent nibh massa, sollicitudin a orci sed, iaculis egestas neque. Integer vestibulum auctor odio, et tempus urna tincidunt sed. Maecenas sit amet nunc at risus varius sodales at sit amet est. Nulla efficitur molestie nisi eget semper. Donec in tempus nisi, id dictum metus. Sed consectetur diam at metus rutrum pulvinar. Nullam pellentesque dolor vel viverra efficitur. Maecenas fermentum varius .

##### List Title

1. Suspendisse commodo condimentum dolor, eu consectetur

2. dui posuere sed. Curabitur eros

3. sem, venenatis consectetur ultricies in, vehicula sodales felis.

4. Donec sem est, pulvinar ac justo sed, posuere malesuada justo. Vivamus sagittis at tortor vitae

##### 5. sodales. Donec sit amet egestas

Parent File Contents